==> zio-aws-robomaker_2.13-5.17.121.2-sources.jar: zio/aws/robomaker/model/DescribeRobotApplicationResponse.scala <==
package zio.aws.robomaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import zio.aws.robomaker.model.primitives.{
  ImageDigest,
  TagValue,
  RevisionId,
  Arn,
  Version,
  Name,
  LastUpdatedAt,
  TagKey
}
import scala.jdk.CollectionConverters._
final case class DescribeRobotApplicationResponse(
    arn: Option[Arn] = None,
    name: Option[Name] = None,
    version: Option[Version] = None,
    sources: Option[Iterable[zio.aws.robomaker.model.Source]] = None,
    robotSoftwareSuite: Option[zio.aws.robomaker.model.RobotSoftwareSuite] =
      None,
    revisionId: Option[RevisionId] = None,
    lastUpdatedAt: Option[LastUpdatedAt] = None,
    tags: Option[Map[TagKey, TagValue]] = None,
    environment: Option[zio.aws.robomaker.model.Environment] = None,
    imageDigest: Option[ImageDigest] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.robomaker.model.DescribeRobotApplicationResponse = {
    import DescribeRobotApplicationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.robomaker.model.DescribeRobotApplicationResponse
      .builder()
      .optionallyWith(arn.map(value => Arn.unwrap(value): java.lang.String))(
        _.arn
      )
      .optionallyWith(name.map(value => Name.unwrap(value): java.lang.String))(
        _.name
      )
      .optionallyWith(
        version.map(value => Version.unwrap(value): java.lang.String)
      )(_.version)
      .optionallyWith(
        sources.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.sources)
      .optionallyWith(robotSoftwareSuite.map(value => value.buildAwsValue()))(
        _.robotSoftwareSuite
      )
      .optionallyWith(
        revisionId.map(value => RevisionId.unwrap(value): java.lang.String)
      )(_.revisionId)
      .optionallyWith(
        lastUpdatedAt.map(value => LastUpdatedAt.unwrap(value): Instant)
      )(_.lastUpdatedAt)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (TagKey.unwrap(key): java.lang.String) -> (TagValue.unwrap(
                value
              ): java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .optionallyWith(environment.map(value => value.buildAwsValue()))(
        _.environment
      )
      .optionallyWith(
        imageDigest.map(value => ImageDigest.unwrap(value): java.lang.String)
      )(_.imageDigest)
      .build()
  }
  def asReadOnly
      : zio.aws.robomaker.model.DescribeRobotApplicationResponse.ReadOnly =
    zio.aws.robomaker.model.DescribeRobotApplicationResponse
      .wrap(buildAwsValue())
}
object DescribeRobotApplicationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.robomaker.model.DescribeRobotApplicationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.robomaker.model.DescribeRobotApplicationResponse =
      zio.aws.robomaker.model.DescribeRobotApplicationResponse(
        arn.map(value => value),
        name.map(value => value),
        version.map(value => value),
        sources.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        robotSoftwareSuite.map(value => value.asEditable),
        revisionId.map(value => value),
        lastUpdatedAt.map(value => value),
        tags.map(value => value),
        environment.map(value => value.asEditable),
        imageDigest.map(value => value)
      )
    def arn: Option[Arn]
    def name: Option[Name]
    def version: Option[Version]
    def sources: Option[List[zio.aws.robomaker.model.Source.ReadOnly]]
    def robotSoftwareSuite
        : Option[zio.aws.robomaker.model.RobotSoftwareSuite.ReadOnly]
    def revisionId: Option[RevisionId]
    def lastUpdatedAt: Option[LastUpdatedAt]
    def tags: Option[Map[TagKey, TagValue]]
    def environment: Option[zio.aws.robomaker.model.Environment.ReadOnly]
    def imageDigest: Option[ImageDigest]
    def getArn: ZIO[Any, AwsError, Arn] = AwsError.unwrapOptionField("arn", arn)
    def getName: ZIO[Any, AwsError, Name] =
      AwsError.unwrapOptionField("name", name)
    def getVersion: ZIO[Any, AwsError, Version] =
      AwsError.unwrapOptionField("version", version)
    def getSources
        : ZIO[Any, AwsError, List[zio.aws.robomaker.model.Source.ReadOnly]] =
      AwsError.unwrapOptionField("sources", sources)
    def getRobotSoftwareSuite: ZIO[
      Any,
      AwsError,
      zio.aws.robomaker.model.RobotSoftwareSuite.ReadOnly
    ] = AwsError.unwrapOptionField("robotSoftwareSuite", robotSoftwareSuite)
    def getRevisionId: ZIO[Any, AwsError, RevisionId] =
      AwsError.unwrapOptionField("revisionId", revisionId)
    def getLastUpdatedAt: ZIO[Any, AwsError, LastUpdatedAt] =
      AwsError.unwrapOptionField("lastUpdatedAt", lastUpdatedAt)
    def getTags: ZIO[Any, AwsError, Map[TagKey, TagValue]] =
      AwsError.unwrapOptionField("tags", tags)
    def getEnvironment
        : ZIO[Any, AwsError, zio.aws.robomaker.model.Environment.ReadOnly] =
      AwsError.unwrapOptionField("environment", environment)
    def getImageDigest: ZIO[Any, AwsError, ImageDigest] =
      AwsError.unwrapOptionField("imageDigest", imageDigest)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.robomaker.model.DescribeRobotApplicationResponse
  ) extends zio.aws.robomaker.model.DescribeRobotApplicationResponse.ReadOnly {
    override val arn: Option[Arn] = scala
      .Option(impl.arn())
      .map(value => zio.aws.robomaker.model.primitives.Arn(value))
    override val name: Option[Name] = scala
      .Option(impl.name())
      .map(value => zio.aws.robomaker.model.primitives.Name(value))
    override val version: Option[Version] = scala
      .Option(impl.version())
      .map(value => zio.aws.robomaker.model.primitives.Version(value))
    override val sources
        : Option[List[zio.aws.robomaker.model.Source.ReadOnly]] = scala
      .Option(impl.sources())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.robomaker.model.Source.wrap(item)
        }.toList
      )
    override val robotSoftwareSuite
        : Option[zio.aws.robomaker.model.RobotSoftwareSuite.ReadOnly] = scala
      .Option(impl.robotSoftwareSuite())
      .map(value => zio.aws.robomaker.model.RobotSoftwareSuite.wrap(value))
    override val revisionId: Option[RevisionId] = scala
      .Option(impl.revisionId())
      .map(value => zio.aws.robomaker.model.primitives.RevisionId(value))
    override val lastUpdatedAt: Option[LastUpdatedAt] = scala
      .Option(impl.lastUpdatedAt())
      .map(value => zio.aws.robomaker.model.primitives.LastUpdatedAt(value))
    override val tags: Option[Map[TagKey, TagValue]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.robomaker.model.primitives
              .TagKey(key) -> zio.aws.robomaker.model.primitives.TagValue(value)
          })
          .toMap
      )
    override val environment
        : Option[zio.aws.robomaker.model.Environment.ReadOnly] = scala
      .Option(impl.environment())
      .map(value => zio.aws.robomaker.model.Environment.wrap(value))
    override val imageDigest: Option[ImageDigest] = scala
      .Option(impl.imageDigest())
      .map(value => zio.aws.robomaker.model.primitives.ImageDigest(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.robomaker.model.DescribeRobotApplicationResponse
  ): zio.aws.robomaker.model.DescribeRobotApplicationResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-robomaker_2.13-5.17.194.1-sources.jar: zio/aws/robomaker/model/DescribeRobotApplicationResponse.scala <==
package zio.aws.robomaker.model
import zio.aws.robomaker.model.primitives.{
  ImageDigest,
  TagValue,
  RevisionId,
  Arn,
  Version,
  Name,
  LastUpdatedAt,
  TagKey
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters._
final case class DescribeRobotApplicationResponse(
    arn: Optional[Arn] = Optional.Absent,
    name: Optional[Name] = Optional.Absent,
    version: Optional[Version] = Optional.Absent,
    sources: Optional[Iterable[zio.aws.robomaker.model.Source]] =
      Optional.Absent,
    robotSoftwareSuite: Optional[zio.aws.robomaker.model.RobotSoftwareSuite] =
      Optional.Absent,
    revisionId: Optional[RevisionId] = Optional.Absent,
    lastUpdatedAt: Optional[LastUpdatedAt] = Optional.Absent,
    tags: Optional[Map[TagKey, TagValue]] = Optional.Absent,
    environment: Optional[zio.aws.robomaker.model.Environment] =
      Optional.Absent,
    imageDigest: Optional[ImageDigest] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.robomaker.model.DescribeRobotApplicationResponse = {
    import DescribeRobotApplicationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.robomaker.model.DescribeRobotApplicationResponse
      .builder()
      .optionallyWith(arn.map(value => Arn.unwrap(value): java.lang.String))(
        _.arn
      )
      .optionallyWith(name.map(value => Name.unwrap(value): java.lang.String))(
        _.name
      )
      .optionallyWith(
        version.map(value => Version.unwrap(value): java.lang.String)
      )(_.version)
      .optionallyWith(
        sources.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.sources)
      .optionallyWith(robotSoftwareSuite.map(value => value.buildAwsValue()))(
        _.robotSoftwareSuite
      )
      .optionallyWith(
        revisionId.map(value => RevisionId.unwrap(value): java.lang.String)
      )(_.revisionId)
      .optionallyWith(
        lastUpdatedAt.map(value => LastUpdatedAt.unwrap(value): Instant)
      )(_.lastUpdatedAt)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (TagKey.unwrap(key): java.lang.String) -> (TagValue.unwrap(
                value
              ): java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .optionallyWith(environment.map(value => value.buildAwsValue()))(
        _.environment
      )
      .optionallyWith(
        imageDigest.map(value => ImageDigest.unwrap(value): java.lang.String)
      )(_.imageDigest)
      .build()
  }
  def asReadOnly
      : zio.aws.robomaker.model.DescribeRobotApplicationResponse.ReadOnly =
    zio.aws.robomaker.model.DescribeRobotApplicationResponse
      .wrap(buildAwsValue())
}
object DescribeRobotApplicationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.robomaker.model.DescribeRobotApplicationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.robomaker.model.DescribeRobotApplicationResponse =
      zio.aws.robomaker.model.DescribeRobotApplicationResponse(
        arn.map(value => value),
        name.map(value => value),
        version.map(value => value),
        sources.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        robotSoftwareSuite.map(value => value.asEditable),
        revisionId.map(value => value),
        lastUpdatedAt.map(value => value),
        tags.map(value => value),
        environment.map(value => value.asEditable),
        imageDigest.map(value => value)
      )
    def arn: Optional[Arn]
    def name: Optional[Name]
    def version: Optional[Version]
    def sources: Optional[List[zio.aws.robomaker.model.Source.ReadOnly]]
    def robotSoftwareSuite
        : Optional[zio.aws.robomaker.model.RobotSoftwareSuite.ReadOnly]
    def revisionId: Optional[RevisionId]
    def lastUpdatedAt: Optional[LastUpdatedAt]
    def tags: Optional[Map[TagKey, TagValue]]
    def environment: Optional[zio.aws.robomaker.model.Environment.ReadOnly]
    def imageDigest: Optional[ImageDigest]
    def getArn: ZIO[Any, AwsError, Arn] = AwsError.unwrapOptionField("arn", arn)
    def getName: ZIO[Any, AwsError, Name] =
      AwsError.unwrapOptionField("name", name)
    def getVersion: ZIO[Any, AwsError, Version] =
      AwsError.unwrapOptionField("version", version)
    def getSources
        : ZIO[Any, AwsError, List[zio.aws.robomaker.model.Source.ReadOnly]] =
      AwsError.unwrapOptionField("sources", sources)
    def getRobotSoftwareSuite: ZIO[
      Any,
      AwsError,
      zio.aws.robomaker.model.RobotSoftwareSuite.ReadOnly
    ] = AwsError.unwrapOptionField("robotSoftwareSuite", robotSoftwareSuite)
    def getRevisionId: ZIO[Any, AwsError, RevisionId] =
      AwsError.unwrapOptionField("revisionId", revisionId)
    def getLastUpdatedAt: ZIO[Any, AwsError, LastUpdatedAt] =
      AwsError.unwrapOptionField("lastUpdatedAt", lastUpdatedAt)
    def getTags: ZIO[Any, AwsError, Map[TagKey, TagValue]] =
      AwsError.unwrapOptionField("tags", tags)
    def getEnvironment
        : ZIO[Any, AwsError, zio.aws.robomaker.model.Environment.ReadOnly] =
      AwsError.unwrapOptionField("environment", environment)
    def getImageDigest: ZIO[Any, AwsError, ImageDigest] =
      AwsError.unwrapOptionField("imageDigest", imageDigest)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.robomaker.model.DescribeRobotApplicationResponse
  ) extends zio.aws.robomaker.model.DescribeRobotApplicationResponse.ReadOnly {
    override val arn: Optional[Arn] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value => zio.aws.robomaker.model.primitives.Arn(value))
    override val name: Optional[Name] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.robomaker.model.primitives.Name(value))
    override val version: Optional[Version] = zio.aws.core.internal
      .optionalFromNullable(impl.version())
      .map(value => zio.aws.robomaker.model.primitives.Version(value))
    override val sources
        : Optional[List[zio.aws.robomaker.model.Source.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.sources())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.robomaker.model.Source.wrap(item)
          }.toList
        )
    override val robotSoftwareSuite
        : Optional[zio.aws.robomaker.model.RobotSoftwareSuite.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.robotSoftwareSuite())
        .map(value => zio.aws.robomaker.model.RobotSoftwareSuite.wrap(value))
    override val revisionId: Optional[RevisionId] = zio.aws.core.internal
      .optionalFromNullable(impl.revisionId())
      .map(value => zio.aws.robomaker.model.primitives.RevisionId(value))
    override val lastUpdatedAt: Optional[LastUpdatedAt] = zio.aws.core.internal
      .optionalFromNullable(impl.lastUpdatedAt())
      .map(value => zio.aws.robomaker.model.primitives.LastUpdatedAt(value))
    override val tags: Optional[Map[TagKey, TagValue]] = zio.aws.core.internal
      .optionalFromNullable(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.robomaker.model.primitives
              .TagKey(key) -> zio.aws.robomaker.model.primitives.TagValue(value)
          })
          .toMap
      )
    override val environment
        : Optional[zio.aws.robomaker.model.Environment.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.environment())
        .map(value => zio.aws.robomaker.model.Environment.wrap(value))
    override val imageDigest: Optional[ImageDigest] = zio.aws.core.internal
      .optionalFromNullable(impl.imageDigest())
      .map(value => zio.aws.robomaker.model.primitives.ImageDigest(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.robomaker.model.DescribeRobotApplicationResponse
  ): zio.aws.robomaker.model.DescribeRobotApplicationResponse.ReadOnly =
    new Wrapper(impl)
}
